@@ -18,7 +18,7 @@
     License along with this library; if not, write to the Free
     Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: IDL.h.new.in,v 1.29 2001/09/24 16:29:02 mmclouglin Exp $
+    $Id: IDL.h.new.in,v 1.31 2003/04/12 08:38:27 msakai Exp $
 
 ***************************************************************************/
 #ifndef __IDL_H
@@ -45,8 +45,8 @@ extern "C" {
 #define LIBIDL_GEN_VERSION(a,b,c)	(((a) << 16) + ((b) << 8) + (c))
 #define LIBIDL_MAJOR_VERSION		0
 #define LIBIDL_MINOR_VERSION		8
-#define LIBIDL_MICRO_VERSION		0
-#define LIBIDL_VERSION_CODE		LIBIDL_GEN_VERSION(0,8,0)
+#define LIBIDL_MICRO_VERSION		2
+#define LIBIDL_VERSION_CODE		LIBIDL_GEN_VERSION(0,8,2)
 
 /* miscellaneous constants */
 #define IDL_SUCCESS			0
@@ -85,8 +85,8 @@ extern "C" {
 #define IDLF_OUTPUT_PROPERTIES		(1UL << 2)
 #define IDLF_OUTPUT_CODEFRAGS		(1UL << 3)
 
-#ifdef _WIN32
-#  define IDL_EXPORT			__declspec (dllexport)
+#ifdef G_PLATFORM_WIN32
+#  define IDL_EXPORT			/* assume auto-export */
 #  define IDL_IMPORT			__declspec (dllimport)
 #else
 #  define IDL_EXPORT			/* empty */
@@ -103,20 +103,10 @@ extern "C" {
 			    __FILE__, __LINE__,			\
 			    G_GNUC_PRETTY_FUNCTION)->u.name)
 
-#ifdef G_HAVE_GINT64
-#  if G_MAXLONG > 0xffffffffUL
-#    define IDL_LL			"l"
-#  else
-#    define IDL_LL			"ll"
-#  endif
-typedef gint64				IDL_longlong_t;
-typedef guint64				IDL_ulonglong_t;
-#else
-#  define IDL_LL			"l"
-typedef long				IDL_longlong_t;
-typedef unsigned long			IDL_ulonglong_t;
-#  warning 64-bit integer type not available, using 32-bit instead
-#endif /* G_HAVE_GINT64 */
+/* GLib 2.0 requires 64-bit types */
+#define IDL_LL		"ll"
+typedef gint64		IDL_longlong_t;
+typedef guint64		IDL_ulonglong_t;
 
 typedef unsigned int			IDL_declspec_t;
 typedef struct _IDL_tree_node 		IDL_tree_node;
